@@ -398,6 +398,12 @@ screenshooter_f1_key (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 void
 screenshooter_get_screen_geometry (GdkRectangle *geometry)
 {
+#if LIBXFCE4UI_CHECK_VERSION (4,14,0)
+  GdkRectangle *geometry2 = xfce_gdk_screen_get_geometry ();
+  geometry->width = geometry2->width;
+  geometry->height = geometry2->height;
+  g_free (geometry2);
+#else
   GdkDisplay *display = gdk_display_get_default ();
   int num_monitors = gdk_display_get_n_monitors (display);
 
@@ -420,6 +426,7 @@ screenshooter_get_screen_geometry (GdkRectangle *geometry)
 
   geometry->width = w - x;
   geometry->height = h - y;
+#endif
 }
 
 
